41#ifndef __NEKO_TOP_CUDA_STEEPEST_DESCENT_KERNELS__
42#define __NEKO_TOP_CUDA_STEEPEST_DESCENT_KERNELS__
62 for (
int i =
idx; i < n; i +=
str) {
65 if ((
xi >= xmax &&
si >
T(0.0)) || (
xi <= xmin &&
si <
T(0.0))) {
90 const T dmax,
const int n) {
95 for (
int i =
idx; i < n; i +=
str) {
96 const T d = (x[i] -
x1[i]) * (
x1[i] -
x2[i]);
100 }
else if (d >
T(0.0)) {
125 const T xmax,
const int n) {
130 for (
int i =
idx; i < n; i +=
str) {
132 const T di = delta[i];
__global__ void sd_update_design_kernel(T *__restrict__ x_new, const T *__restrict__ x, const T *__restrict__ s, const T *__restrict__ delta, const T psi, const T smax, const T xmin, const T xmax, const int n)
__global__ void sd_update_move_limits_kernel(T *__restrict__ delta, const T *__restrict__ x, const T *__restrict__ x1, const T *__restrict__ x2, const T dec, const T inc, const T dmin, const T dmax, const int n)
__global__ void sd_direction_kernel(T *__restrict__ s, const T *__restrict__ x, const T xmin, const T xmax, const int n)